@@ -106,10 +106,10 @@ class BasicNetMonitor(Monitor):
     verbose_name = 'Network IO (%(iface)s)'
     relativity_fields = ['RX', 'TX']
     cmd = (
-        'grep %(iface)s /proc/net/dev | awk -F "[ :]*" {\'print "{'
-        ' \\"RX\\": "$2",'
-        ' \\"TX\\": "$10"'
-        '}"\'}'
+       'grep %(iface)s /proc/net/dev | sed "s/^\s*//" | awk -F "[ :]*" {\'print "{'
+       ' \\"RX\\": "$2",'
+       ' \\"TX\\": "$10"'
+       '}"\'}'
     )
 
 
