@@ -4,7 +4,7 @@ from django.core.exceptions import ValidationError
 
 from api import serializers
 
-from .models import User, Group, Roles
+from .models import AuthToken, User, Group, Roles
 
 
 class GroupRolesSerializer(serializers.ModelSerializer):
@@ -13,6 +13,13 @@ class GroupRolesSerializer(serializers.ModelSerializer):
     class Meta:
         model = Roles
         exclude = ['id', 'user']
+    
+    def get_identity(self, data):
+        try:
+            group = data.get('group', {})
+            return group.get('uri')
+        except AttributeError:
+            return None
 
 
 class UserRolesSerializer(serializers.ModelSerializer):
@@ -21,11 +28,31 @@ class UserRolesSerializer(serializers.ModelSerializer):
     class Meta:
         model = Roles
         exclude = ['id', 'group']
+    
+    def get_identity(self, data):
+        try:
+            group = data.get('user', {})
+            return group.get('uri')
+        except AttributeError:
+            return None
 
 
 class AuthTokenField(serializers.WritableField):
     def to_native(self, value):
         return [ token.data for token in value.all() ]
+    
+    def from_native(self, value):
+        user_tokens = AuthToken.objects.filter(user=self.parent.object)
+        auth_tokens = []
+        for v in value:
+            token = user_tokens.filter(data=v).first()
+            if token is None:
+                auth_tokens.append(AuthToken(data=v))
+            else:
+                user_tokens = user_tokens.exclude(pk=token.pk)
+        # clean up old auth_tokens
+        user_tokens.delete()
+        return auth_tokens
 
 
 class UserCreateSerializer(serializers.UriHyperlinkedModelSerializer):
@@ -40,7 +67,7 @@ class UserCreateSerializer(serializers.UriHyperlinkedModelSerializer):
 
 
 class UserSerializer(UserCreateSerializer, serializers.DynamicReadonlyFieldsModelSerializer):
-    group_roles = GroupRolesSerializer(source='roles', required=False)
+    group_roles = GroupRolesSerializer(source='roles', required=False, many=True, allow_add_remove=True)
     is_active = serializers.BooleanField()
     is_superuser = serializers.BooleanField()
     
@@ -58,7 +85,7 @@ class GroupCreateSerializer(serializers.UriHyperlinkedModelSerializer):
 
 
 class GroupSerializer(GroupCreateSerializer, serializers.DynamicReadonlyFieldsModelSerializer):
-    user_roles = UserRolesSerializer(source='roles', required=False, many=True)
+    user_roles = UserRolesSerializer(source='roles', many=True, allow_add_remove=True)
     allow_nodes = serializers.BooleanField()
     allow_slices = serializers.BooleanField()
     slices = serializers.RelHyperlinkedRelatedField(many=True, source='slices',
