@@ -231,12 +231,12 @@ FLUENT_DASHBOARD_APP_ICONS = {
     'users/group': "research_group.png",
     'nodes/node': "linksys-WRT54G.png",
     'nodes/server': "poweredge_r510.png",
+    'nodes/island': "Weather-overcast.png",
     'nodes/researchdevice': "western-digital-mybook-pro.png",
     'slices/slice': "ChemSlice.png",
     'slices/sliver': "LXCBox2.png",
     'slices/template': "Application-x-gerber.png",
     'tinc/gateway': "Network.png",
-    'tinc/island': "Weather-overcast.png",
     'tinc/tincaddress': "X-office-address-book.png",
     'tinc/host': "computer-dell-dimension-E521.png",
     'issues/ticket': "Ticket_star.png",
